from typing import List, Dict, Any

from malloryai.sdk.api.v1.decorators.sorting import validate_sorting
from malloryai.sdk.api.v1.http_client import HttpClient


class ExploitationsClient:
    """Client for managing exploitations."""

    def __init__(self, http_client: HttpClient):
        self.http_client = http_client

    @validate_sorting
    async def list_exploitations(
        self,
        offset: int = 0,
        limit: int = 100,
        sort: str = "created_at",
        order: str = "desc",
    ) -> List[Dict[str, Any]]:
        """
        List exploitations.
        :param offset: Offset for pagination.
        :param limit: Limit for pagination.
        :param sort: Sorting field.
        :param order: Sorting order.
        :return: List of exploitations.
        """
        params = {"offset": offset, "limit": limit, "sort": sort, "order": order}
        return await self.http_client.get("/exploitations", params=params)

    async def get_exploitation(self, identifier: str) -> Dict[str, Any]:
        """
        Fetch details of a specific exploitation.
        :param identifier: Identifier of the exploitation.
        :return: Details of the exploitation.
        """
        return await self.http_client.get(f"/exploitations/{identifier}")
